@@ -242,7 +242,7 @@ macro(conan_set_std)
                                        OR "${CONAN_CMAKE_CXX_STANDARD}" STREQUAL "gnu20")
     if(CONAN_STD_CXX_FLAG)
       message(STATUS "Conan setting CXX_FLAGS flags: ${CONAN_STD_CXX_FLAG}")
-      set(CMAKE_CXX_FLAGS "-std=${CONAN_STD_CXX_FLAG} ${CMAKE_CXX_FLAGS}")
+      set(CMAKE_CXX_FLAGS "${CONAN_STD_CXX_FLAG} ${CMAKE_CXX_FLAGS}")
     endif()
   else()
     if(CONAN_CMAKE_CXX_STANDARD)
